@@ -8,14 +8,11 @@ from typing import Callable, Dict, List, NamedTuple, Tuple, Union
 
 import numpy as np
 import pandas as pd
-
 from desdeo_problem.surrogatemodels.SurrogateModels import BaseRegressor, ModelError
 
 
 class ObjectiveError(Exception):
-    """Raised when an error related to the Objective class is encountered.
-
-    """
+    """Raised when an error related to the Objective class is encountered."""
 
 
 class ObjectiveEvaluationResults(NamedTuple):
@@ -47,9 +44,7 @@ class ObjectiveEvaluationResults(NamedTuple):
 
 
 class ObjectiveBase(ABC):
-    """The abstract base class for objectives.
-
-    """
+    """The abstract base class for objectives."""
 
     def evaluate(self, decision_vector: np.ndarray, use_surrogate: bool = False) -> ObjectiveEvaluationResults:
         """Evaluates the objective according to a decision variable vector.
@@ -99,9 +94,7 @@ class ObjectiveBase(ABC):
 
 
 class VectorObjectiveBase(ABC):
-    """The abstract base class for multiple objectives which are calculated at once.
-
-    """
+    """The abstract base class for multiple objectives which are calculated at once."""
 
     def evaluate(self, decision_vector: np.ndarray, use_surrogate: bool = False) -> ObjectiveEvaluationResults:
         """Evaluates the objective according to a decision variable vector.
@@ -293,9 +286,11 @@ class ScalarObjective(ObjectiveBase):
         """
         raise ObjectiveError("Surrogates not trained")
 
+
 class _ScalarObjective(ScalarObjective):
     pass
 
+
 # TODO: Rename to "Objective"
 class VectorObjective(VectorObjectiveBase):
     """An objective object that calculated one or more objective functions.
@@ -528,7 +523,11 @@ class ScalarDataObjective(ScalarObjective):
         self.__evaluator = evaluator #this is how we added analatycal function
 
     def train(
-        self, model: BaseRegressor, model_parameters: Dict = None, index: List[int] = None, data: pd.DataFrame = None
+        self,
+        model: BaseRegressor,
+        model_parameters: Dict = None,
+        index: List[int] = None,
+        data: pd.DataFrame = None,
     ):
         """Train surrogate model for the objective.
 
@@ -615,9 +614,11 @@ class ScalarDataObjective(ScalarObjective):
          
         return results
 
+
 class _ScalarDataObjective(ScalarDataObjective):
     pass
 
+
 class VectorDataObjective(VectorObjective):
     """A Objective class for multi/valued objectives.      
 
