@@ -1,9 +1,10 @@
-__all__ = ["test_problem_builder"]
+__all__ = ["test_problem_builder", "dummy_problem"]
 
 
 # __all__ = ["test_problem_builder", "DBMOPP_generator", "Region", "get_2D_version", "euclidean_distance", "convhull", "in_hull", "get_random_angles", "between_lines_rooted_at_pivot", "assign_design_dimension_projection"]
 
 from desdeo_problem.testproblems.TestProblems import test_problem_builder
+from desdeo_problem.testproblems.DummyProblem import dummy_problem
 
 # from desdeo_problem.testproblems.DBMOPP.DBMOPP_generator import DBMOPP_generator
 # from desdeo_problem.testproblems.DBMOPP.Region import Region
